@@ -1,5 +1,24 @@
-#ifndef _SIGC_ADAPTORS_ADAPTOR_TRAIT_H_
-#define _SIGC_ADAPTORS_ADAPTOR_TRAIT_H_
+/*
+ * Copyright 2003 - 2016, The libsigc++ Development Team
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ */
+
+#ifndef SIGC_ADAPTORS_ADAPTOR_TRAIT_H
+#define SIGC_ADAPTORS_ADAPTOR_TRAIT_H
+
 #include <sigc++config.h> //To get SIGC_TEMPLATE_KEYWORD_OPERATOR_OVERLOAD
 #include <sigc++/visit_each.h>
 #include <sigc++/functors/functor_trait.h>
@@ -62,7 +81,7 @@ namespace sigc
  *
  * @ingroup adaptors
  */
-template <class T_functor>
+template <typename T_functor>
 struct adaptor_functor : public adaptor_base
 {
   /** Invokes the wrapped functor passing on the arguments.
@@ -71,29 +90,29 @@ struct adaptor_functor : public adaptor_base
   decltype(auto) operator()() const { return functor_(); }
 
   /** Invokes the wrapped functor passing on the arguments.
-   * @param _A_arg... Arguments to be passed on to the functor.
+   * @param arg Arguments to be passed on to the functor.
    * @return The return value of the functor invocation.
    */
-  template <class... T_arg>
-  decltype(auto) operator()(T_arg&&... _A_arg) const
+  template <typename... T_arg>
+  decltype(auto) operator()(T_arg&&... arg) const
   {
-    return functor_(std::forward<T_arg>(_A_arg)...);
+    return functor_(std::forward<T_arg>(arg)...);
   }
 
   /// Constructs an invalid functor.
   adaptor_functor() = default;
 
   /** Constructs an adaptor_functor object that wraps the passed functor.
-   * @param _A_functor Functor to invoke from operator()().
+   * @param functor Functor to invoke from operator()().
    */
-  explicit adaptor_functor(const T_functor& _A_functor) : functor_(_A_functor) {}
+  explicit adaptor_functor(const T_functor& functor) : functor_(functor) {}
 
   /** Constructs an adaptor_functor object that wraps the passed (member)
    * function pointer.
-   * @param _A_type Pointer to function or class method to invoke from operator()().
+   * @param type Pointer to function or class method to invoke from operator()().
    */
-  template <class T_type>
-  explicit adaptor_functor(const T_type& _A_type) : functor_(_A_type)
+  template <typename T_type>
+  explicit adaptor_functor(const T_type& type) : functor_(type)
   {
   }
 
@@ -109,13 +128,13 @@ struct adaptor_functor : public adaptor_base
  *
  * @ingroup adaptors
  */
-template <class T_functor>
+template <typename T_functor>
 struct visitor<adaptor_functor<T_functor>>
 {
-  template <class T_action>
-  static void do_visit_each(const T_action& _A_action, const adaptor_functor<T_functor>& _A_target)
+  template <typename T_action>
+  static void do_visit_each(const T_action& action, const adaptor_functor<T_functor>& target)
   {
-    sigc::visit_each(_A_action, _A_target.functor_);
+    sigc::visit_each(action, target.functor_);
   }
 };
 #endif // DOXYGEN_SHOULD_SKIP_THIS
@@ -129,7 +148,7 @@ struct visitor<adaptor_functor<T_functor>>
  *
  * @ingroup adaptors
  */
-template <class T_functor, bool I_isadaptor = std::is_base_of<adaptor_base, T_functor>::value>
+template <typename T_functor, bool I_isadaptor = std::is_base_of<adaptor_base, T_functor>::value>
 struct adaptor_trait;
 
 
@@ -137,7 +156,7 @@ struct adaptor_trait;
  * This template specialization is used for types that inherit from adaptor_base.
  * adaptor_type is equal to @p T_functor in this case.
  */
-template <class T_functor>
+template <typename T_functor>
 struct adaptor_trait<T_functor, true>
 {
   using adaptor_type = T_functor;
@@ -149,7 +168,7 @@ struct adaptor_trait<T_functor, true>
  * The latter are converted into @p pointer_functor or @p mem_functor types.
  * adaptor_type is equal to @p adaptor_functor<functor_type>.
  */
-template <class T_functor>
+template <typename T_functor>
 struct adaptor_trait<T_functor, false>
 {
 private:
@@ -160,4 +179,4 @@ public:
 };
 
 } /* namespace sigc */
-#endif /* _SIGC_ADAPTORS_ADAPTOR_TRAIT_H_ */
+#endif /* SIGC_ADAPTORS_ADAPTOR_TRAIT_H */
