@@ -1,5 +1,5 @@
 /*
- * Copyright 2002, The libsigc++ Development Team
+ * Copyright 2002 - 2016, The libsigc++ Development Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -16,10 +16,10 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
-#ifndef _SIGC_CONNECTION_HPP_
-#define _SIGC_CONNECTION_HPP_
+#ifndef SIGC_CONNECTION_HPP
+#define SIGC_CONNECTION_HPP
 #include <sigc++config.h>
-#include <sigc++/signal.h>
+#include <sigc++/functors/slot_base.h>
 
 namespace sigc
 {
@@ -48,36 +48,15 @@ struct SIGC_API connection : public notifiable
    */
   connection(const connection& c);
 
-  /** Constructs a connection object from a slot list iterator.
-   * @param it The slot list iterator to take the slot from.
-   */
-  template <typename T_slot>
-  connection(const slot_iterator<T_slot>& it) : slot_(&(*it))
-  {
-    if (slot_)
-      slot_->add_destroy_notify_callback(this, &notify);
-  }
-
   /** Constructs a connection object from a slot object.
-   * This is only useful if you create your own slot list.
    * @param sl The slot to operate on.
    */
-  explicit connection(slot_base& sl);
+  explicit connection(slot_base& slot);
 
   /** Overrides this connection object copying another one.
    * @param c The connection object to make a copy from.
    */
-  connection& operator=(const connection& c);
-
-  /** Overrides this connection object with another slot list iterator.
-   * @param it The new slot list iterator to take the slot from.
-   */
-  template <typename T_slot>
-  connection& operator=(const slot_iterator<T_slot>& it)
-  {
-    set_slot(&(*it));
-    return *this;
-  }
+  connection& operator=(const connection& src);
 
   ~connection();
 
@@ -116,13 +95,13 @@ struct SIGC_API connection : public notifiable
    */
   explicit operator bool() const noexcept;
 
+private:
+  void set_slot(slot_base* sl);
+
   /** Callback that is executed when the referred slot is destroyed.
    * @param data The connection object notified (@p this).
    */
-  static void notify(notifiable* data);
-
-private:
-  void set_slot(slot_base* sl);
+  static void notify_slot_invalidated(notifiable* data);
 
   /* Referred slot. Set to zero from notify().
    * A value of zero indicates an "empty" connection.
@@ -132,4 +111,4 @@ private:
 
 } /* namespace sigc */
 
-#endif /* _SIGC_TRACKABLE_HPP_ */
+#endif /* SIGC_TRACKABLE_HPP */
