@@ -1,5 +1,23 @@
-#ifndef _SIGC_FUNCTORS_PTR_FUN_H_
-#define _SIGC_FUNCTORS_PTR_FUN_H_
+/*
+ * Copyright 2003 - 2016, The libsigc++ Development Team
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ */
+
+#ifndef SIGC_FUNCTORS_PTR_FUN_H
+#define SIGC_FUNCTORS_PTR_FUN_H
 #include <sigc++/type_traits.h>
 
 namespace sigc
@@ -49,10 +67,10 @@ namespace sigc
  *
  * @ingroup ptr_fun
  */
-template <class T_return, class... T_args>
+template <typename T_return, typename... T_args>
 class pointer_functor;
 
-template <class T_return, class... T_args>
+template <typename T_return, typename... T_args>
 class pointer_functor<T_return(T_args...)>
 {
   using function_type = T_return (*)(T_args...);
@@ -66,29 +84,28 @@ public:
   pointer_functor() = default;
 
   /** Constructs a pointer_functor2 object that wraps an existing function.
-   * @param _A_func Pointer to function that will be invoked from operator()().
+   * @param func Pointer to function that will be invoked from operator()().
    */
-  explicit pointer_functor(function_type _A_func) : func_ptr_(_A_func) {}
+  explicit pointer_functor(function_type func) : func_ptr_(func) {}
 
   /** Execute the wrapped function.
-   * @param _A_a1 Argument to be passed on to the function.
-   * @param _A_a2 Argument to be passed on to the function.
+   * @param a Arguments to be passed on to the function.
    * @return The return value of the function invocation.
    */
-  T_return operator()(type_trait_take_t<T_args>... _A_a) const { return func_ptr_(_A_a...); }
+  T_return operator()(type_trait_take_t<T_args>... a) const { return func_ptr_(a...); }
 };
 
 /** Creates a functor of type sigc::pointer_functor which wraps an existing non-member function.
- * @param _A_func Pointer to function that should be wrapped.
- * @return Functor that executes @e _A_func on invokation.
+ * @param func Pointer to function that should be wrapped.
+ * @return Functor that executes @e func on invokation.
  *
  * @ingroup ptr_fun
  */
-template <class T_return, class... T_args>
-inline decltype(auto) ptr_fun(T_return (*_A_func)(T_args...))
+template <typename T_return, typename... T_args>
+inline decltype(auto) ptr_fun(T_return (*func)(T_args...))
 {
-  return pointer_functor<T_return(T_args...)>(_A_func);
+  return pointer_functor<T_return(T_args...)>(func);
 }
 
 } /* namespace sigc */
-#endif /* _SIGC_FUNCTORS_PTR_FUN_H_ */
+#endif /* SIGC_FUNCTORS_PTR_FUN_H */
