@@ -1,11 +1,31 @@
-#ifndef _SIGC_FUNCTORS_SLOT_H_
-#define _SIGC_FUNCTORS_SLOT_H_
+/*
+ * Copyright 2003 - 2016, The libsigc++ Development Team
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ */
+
+#ifndef SIGC_FUNCTORS_SLOT_H
+#define SIGC_FUNCTORS_SLOT_H
 
 #include <sigc++/trackable.h>
 #include <sigc++/visit_each.h>
 #include <sigc++/adaptors/adaptor_trait.h>
 #include <sigc++/functors/slot_base.h>
 
+#include <memory>
+
 namespace sigc
 {
 
@@ -19,7 +39,7 @@ namespace internal
  * notification callback. Consequently the slot_rep object will be
  * notified when some referred object is destroyed or overwritten.
  */
-template <class T_functor>
+template <typename T_functor>
 struct typed_slot_rep : public slot_rep
 {
 private:
@@ -31,22 +51,22 @@ private:
 public:
 
   /** The functor contained by this slot_rep object. */
-  adaptor_type functor_;
+  std::unique_ptr<adaptor_type> functor_;
 
   /** Constructs an invalid typed slot_rep object.
    * The notification callback is registered using visit_each().
    * @param functor The functor contained by the new slot_rep object.
    */
-  inline typed_slot_rep(const T_functor& functor)
-  : slot_rep(nullptr, &destroy, &dup), functor_(functor)
+  inline explicit typed_slot_rep(const T_functor& functor)
+  : slot_rep(nullptr, &destroy, &dup), functor_(std::make_unique<adaptor_type>(functor))
   {
-    sigc::visit_each_type<trackable*>(slot_do_bind(this), functor_);
+    sigc::visit_each_trackable(slot_do_bind(this), *functor_);
   }
 
-  inline typed_slot_rep(const typed_slot_rep& cl)
-  : slot_rep(cl.call_, &destroy, &dup), functor_(cl.functor_)
+  inline typed_slot_rep(const typed_slot_rep& src)
+    : slot_rep(src.call_, &destroy, &dup), functor_(std::make_unique<adaptor_type>(*src.functor_))
   {
-    sigc::visit_each_type<trackable*>(slot_do_bind(this), functor_);
+    sigc::visit_each_trackable(slot_do_bind(this), *functor_);
   }
 
   typed_slot_rep& operator=(const typed_slot_rep& src) = delete;
@@ -58,7 +78,7 @@ public:
   {
     call_ = nullptr;
     destroy_ = nullptr;
-    sigc::visit_each_type<trackable*>(slot_do_unbind(this), functor_);
+    sigc::visit_each_trackable(slot_do_unbind(this), *functor_);
   }
 
 private:
@@ -67,11 +87,11 @@ private:
    */
   static void destroy(notifiable* data)
   {
-    self* self_ = static_cast<self*>(reinterpret_cast<slot_rep*>(data));
+    auto self_ = static_cast<self*>(data);
     self_->call_ = nullptr;
     self_->destroy_ = nullptr;
-    sigc::visit_each_type<trackable*>(slot_do_unbind(self_), self_->functor_);
-    self_->functor_.~adaptor_type();
+    sigc::visit_each_trackable(slot_do_unbind(self_), *self_->functor_);
+    self_->functor_.reset(nullptr);
     /* don't call disconnect() here: destroy() is either called
      * a) from the parent itself (in which case disconnect() leads to a segfault) or
      * b) from a parentless slot (in which case disconnect() does nothing)
@@ -97,19 +117,18 @@ private:
  * - @e T_arg Argument types used in the definition of call_it().
  *
  */
-template <class T_functor, class T_return, class... T_arg>
+template <typename T_functor, typename T_return, typename... T_arg>
 struct slot_call
 {
   /** Invokes a functor of type @p T_functor.
    * @param rep slot_rep object that holds a functor of type @p T_functor.
-   * @param _A_a Arguments to be passed on to the functor.
+   * @param a Arguments to be passed on to the functor.
    * @return The return values of the functor invocation.
    */
   static T_return call_it(slot_rep* rep, type_trait_take_t<T_arg>... a_)
   {
-    using typed_slot = typed_slot_rep<T_functor>;
-    typed_slot* typed_rep = static_cast<typed_slot*>(rep);
-    return (typed_rep->functor_).template operator()<type_trait_take_t<T_arg>...>(a_...);
+    auto typed_rep = static_cast<typed_slot_rep<T_functor>*>(rep);
+    return (*typed_rep->functor_).template operator()<type_trait_take_t<T_arg>...>(a_...);
   }
 
   /** Forms a function pointer from call_it().
@@ -149,10 +168,10 @@ struct slot_call
  *
  * @ingroup slot
  */
-template <class T_return, class... T_arg>
+template <typename T_return, typename... T_arg>
 class slot;
 
-template <class T_return, class... T_arg>
+template <typename T_return, typename... T_arg>
 class slot<T_return(T_arg...)> : public slot_base
 {
 public:
@@ -167,23 +186,23 @@ public:
 #endif
 
   /** Invoke the contained functor unless slot is in blocking state.
-   * @param _A_a Arguments to be passed on to the functor.
+   * @param a Arguments to be passed on to the functor.
    * @return The return value of the functor invocation.
    */
-  inline T_return operator()(type_trait_take_t<T_arg>... _A_a) const
+  inline T_return operator()(type_trait_take_t<T_arg>... a) const
   {
     if (!empty() && !blocked())
-      return (reinterpret_cast<call_type>(slot_base::rep_->call_))(slot_base::rep_, _A_a...);
+      return (reinterpret_cast<call_type>(slot_base::rep_->call_))(slot_base::rep_, a...);
     return T_return();
   }
 
   inline slot() = default;
 
   /** Constructs a slot from an arbitrary functor.
-   * @param _A_func The desired functor the new slot should be assigned to.
+   * @param func The desired functor the new slot should be assigned to.
    */
-  template <class T_functor>
-  slot(const T_functor& _A_func) : slot_base(new internal::typed_slot_rep<T_functor>(_A_func))
+  template <typename T_functor>
+  slot(const T_functor& func) : slot_base(new internal::typed_slot_rep<T_functor>(func))
   {
     // The slot_base:: is necessary to stop the HP-UX aCC compiler from being confused. murrayc.
     slot_base::rep_->call_ = internal::slot_call<T_functor, T_return, T_arg...>::address();
@@ -246,29 +265,29 @@ template <typename T_return, typename... T_arg>
 struct visitor<slot<T_return, T_arg...>>
 {
   static void do_visit_each(
-    const internal::limit_derived_target<trackable*, internal::slot_do_bind>& _A_action,
-    const slot<T_return, T_arg...>& _A_target)
+    const internal::limit_trackable_target<internal::slot_do_bind>& action,
+    const slot<T_return, T_arg...>& target)
   {
-    if (_A_target.rep_ && _A_target.rep_->parent_ == nullptr)
-      _A_target.rep_->set_parent(_A_action.action_.rep_, &internal::slot_rep::notify);
+    if (target.rep_ && target.rep_->parent_ == nullptr)
+      target.rep_->set_parent(action.action_.rep_, &internal::slot_rep::notify_slot_rep_invalidated);
   }
 
   static void do_visit_each(
-    const internal::limit_derived_target<trackable*, internal::slot_do_unbind>& _A_action,
-    const slot<T_return, T_arg...>& _A_target)
+    const internal::limit_trackable_target<internal::slot_do_unbind>& action,
+    const slot<T_return, T_arg...>& target)
   {
-    if (_A_target.rep_ && _A_target.rep_->parent_ == _A_action.action_.rep_)
-      _A_target.rep_->set_parent(nullptr, nullptr);
+    if (target.rep_ && target.rep_->parent_ == action.action_.rep_)
+      target.rep_->unset_parent();
   }
 
   template <typename T_action>
-  static void do_visit_each(const T_action& _A_action, const slot<T_return, T_arg...>& _A_target)
+  static void do_visit_each(const T_action& action, const slot<T_return, T_arg...>& target)
   {
-    _A_action(_A_target);
+    action(target);
   }
 };
 #endif // DOXYGEN_SHOULD_SKIP_THIS
 
 } /* namespace sigc */
 
-#endif /* _SIGC_FUNCTORS_SLOT_H_ */
+#endif /* SIGC_FUNCTORS_SLOT_H */
