@@ -1,5 +1,5 @@
 /*
- * Copyright 2003, The libsigc++ Development Team
+ * Copyright 2003 - 2016, The libsigc++ Development Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -29,7 +29,7 @@ struct destroy_notify_struct : public sigc::notifiable
 
   static void notify(notifiable* data) noexcept
   {
-    auto self_ = reinterpret_cast<destroy_notify_struct*>(data);
+    auto self_ = static_cast<destroy_notify_struct*>(data);
     self_->deleted_ = true;
   }
 
@@ -77,9 +77,9 @@ slot_rep::disconnect()
 
 // static
 void
-slot_rep::notify(notifiable* data)
+slot_rep::notify_slot_rep_invalidated(notifiable* data)
 {
-  auto self_ = reinterpret_cast<slot_rep*>(data);
+  auto self_ = static_cast<slot_rep*>(data);
 
   self_->call_ = nullptr; // Invalidate the slot.
 
@@ -91,9 +91,10 @@ slot_rep::notify(notifiable* data)
   if (!notifier.deleted_)
   {
     self_->remove_destroy_notify_callback(&notifier);
-    self_
-      ->destroy(); // Detach the stored functor from the other referred trackables and destroy it.
+
+    // Detach the stored functor from the other referred trackables and destroy it.
     // destroy() might lead to deletion of self_. Bug #564005.
+    self_->destroy();
   }
 }
 
