@@ -1,5 +1,5 @@
 /*
- * Copyright 2003, The libsigc++ Development Team
+ * Copyright 2003 - 2016, The libsigc++ Development Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -16,8 +16,8 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
-#ifndef _SIGC_SLOT_BASE_HPP_
-#define _SIGC_SLOT_BASE_HPP_
+#ifndef SIGC_SLOT_BASE_HPP
+#define SIGC_SLOT_BASE_HPP
 
 #include <sigc++config.h>
 #include <sigc++/trackable.h>
@@ -54,6 +54,7 @@ using hook = void* (*)(void*);
  */
 struct SIGC_API slot_rep : public trackable
 {
+public:
   slot_rep(const slot_rep& src) = delete;
   slot_rep& operator=(const slot_rep& src) = delete;
 
@@ -65,7 +66,6 @@ struct SIGC_API slot_rep : public trackable
    * down dereferencing of slot list iterators. Martin. */
   // TODO: Try this now? murrayc.
 
-public:
   using hook_dup = slot_rep* (*)(slot_rep*);
 
   inline slot_rep(hook call__, notifiable::func_destroy_notify destroy__, hook_dup dup__) noexcept
@@ -98,7 +98,7 @@ public:
    */
   inline slot_rep* dup() const
   {
-    return reinterpret_cast<slot_rep*>((*dup_)(const_cast<slot_rep*>(this)));
+    return static_cast<slot_rep*>((*dup_)(const_cast<slot_rep*>(this)));
   }
 
   /** Set the parent with a callback.
@@ -112,6 +112,15 @@ public:
     cleanup_ = cleanup;
   }
 
+  /** See set_parent().
+   *
+   */
+  inline void unset_parent() noexcept
+  {
+    parent_ = nullptr;
+    cleanup_ = nullptr;
+  }
+
   /// Invalidates the slot and executes the parent's cleanup callback.
   void disconnect();
 
@@ -122,8 +131,9 @@ public:
    * referred object dying.
    * @param data The slot_rep object that is becoming invalid (@p this).
    */
-  static void notify(notifiable* data);
+  static void notify_slot_rep_invalidated(notifiable* data);
 
+public:
   /// Callback that invokes the contained functor.
   /* This can't be a virtual function since number of arguments
    * must be flexible. We use function pointers to slot_call::call_it()
@@ -168,9 +178,9 @@ struct SIGC_API slot_do_bind
   /** Adds a dependency to @p t.
    * @param t The trackable object to add a callback to.
    */
-  inline void operator()(const trackable* t) const
+  inline void operator()(const trackable& t) const
   {
-    t->add_destroy_notify_callback(rep_, &slot_rep::notify);
+    t.add_destroy_notify_callback(rep_, &slot_rep::notify_slot_rep_invalidated);
   }
 };
 
@@ -188,7 +198,7 @@ struct SIGC_API slot_do_unbind
   /** Removes a dependency from @p t.
    * @param t The trackable object to remove the callback from.
    */
-  inline void operator()(const trackable* t) const { t->remove_destroy_notify_callback(rep_); }
+  inline void operator()(const trackable& t) const { t.remove_destroy_notify_callback(rep_); }
 };
 
 } // namespace internal
@@ -397,4 +407,4 @@ private:
 
 } // namespace sigc
 
-#endif //_SIGC_SLOT_BASE_HPP_
+#endif //SIGC_SLOT_BASE_HPP
