@@ -1,5 +1,5 @@
 /*
- * Copyright 2003, The libsigc++ Development Team
+ * Copyright 2003 - 2016, The libsigc++ Development Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -28,27 +28,20 @@ namespace internal
 // when the slot is disconnected. Bug 167714.
 struct self_and_iter : public notifiable
 {
-  signal_impl* self_;
-  signal_impl::iterator_type iter_;
+  const std::shared_ptr<signal_impl> self_;
+  const signal_impl::iterator_type iter_;
 
-  self_and_iter(signal_impl* self, signal_impl::iterator_type iter) : self_(self), iter_(iter) {}
+  self_and_iter(const std::shared_ptr<signal_impl>& self, const signal_impl::iterator_type& iter) : self_(self), iter_(iter) {}
 };
 
-signal_impl::signal_impl() : ref_count_(0), exec_count_(0), deferred_(false)
+signal_impl::signal_impl() : exec_count_(0), deferred_(false)
 {
 }
 
 signal_impl::~signal_impl()
 {
-  // unreference() must not call ~signal_impl() while clear() is executing.
-  ++ref_count_;
-
   // Disconnect all slots before *this is deleted.
   clear();
-
-  // Now ref_count_ can be cleared again (not really necessary), but don't do it
-  // with a call to unreference(). That would invoke ~signal_impl() recursively.
-  --ref_count_;
 }
 
 // only MSVC needs this to guarantee that all new/delete are executed from the DLL module
@@ -72,7 +65,7 @@ signal_impl::clear()
   // Don't let signal_impl::notify() erase the slots. It would invalidate the
   // iterator in the following loop.
   const bool saved_deferred = deferred_;
-  signal_exec exec(this);
+  signal_impl_exec_holder(this);
 
   // Disconnect all connected slots before they are deleted.
   // signal_impl::notify() will be called and delete the self_and_iter structs.
@@ -128,7 +121,7 @@ signal_impl::erase(iterator_type i)
   // Don't let signal_impl::notify() erase the slot. It would be more
   // difficult to get the correct return value from signal_impl::erase().
   const bool saved_deferred = deferred_;
-  signal_exec exec(this);
+  signal_impl_holder exec(shared_from_this());
 
   // Disconnect the slot before it is deleted.
   // signal_impl::notify() will be called and delete the self_and_iter struct.
@@ -139,22 +132,27 @@ signal_impl::erase(iterator_type i)
   return slots_.erase(i);
 }
 
+void
+signal_impl::add_notification_to_iter(const signal_impl::iterator_type& iter)
+{
+  auto si = new self_and_iter(shared_from_this(), iter);
+  iter->set_parent(si, &signal_impl::notify_self_and_iter_of_invalidated_slot);
+}
+
 signal_impl::iterator_type
 signal_impl::insert(signal_impl::iterator_type i, const slot_base& slot_)
 {
-  auto temp = slots_.insert(i, slot_);
-  auto si = new self_and_iter(this, temp);
-  temp->set_parent(si, &notify);
-  return temp;
+  auto iter = slots_.insert(i, slot_);
+  add_notification_to_iter(iter);
+  return iter;
 }
 
 signal_impl::iterator_type
 signal_impl::insert(signal_impl::iterator_type i, slot_base&& slot_)
 {
-  auto temp = slots_.insert(i, std::move(slot_));
-  auto si = new self_and_iter(this, temp);
-  temp->set_parent(si, &notify);
-  return temp;
+  auto iter = slots_.insert(i, std::move(slot_));
+  add_notification_to_iter(iter);
+  return iter;
 }
 
 void
@@ -162,8 +160,8 @@ signal_impl::sweep()
 {
   // The deletion of a slot may cause the deletion of a signal_base,
   // a decrementation of ref_count_, and the deletion of this.
-  // In that case, the deletion of this is deferred to ~signal_exec().
-  signal_exec exec(this);
+  // In that case, the deletion of this is deferred to ~signal_impl_holder().
+  signal_impl_holder exec(shared_from_this());
 
   deferred_ = false;
   auto i = slots_.begin();
@@ -178,7 +176,7 @@ signal_impl::sweep()
 
 // static
 void
-signal_impl::notify(notifiable* d)
+signal_impl::notify_self_and_iter_of_invalidated_slot(notifiable* d)
 {
   std::unique_ptr<self_and_iter> si(static_cast<self_and_iter*>(d));
 
@@ -186,14 +184,14 @@ signal_impl::notify(notifiable* d)
   {
     // The deletion of a slot may cause the deletion of a signal_base,
     // a decrementation of si->self_->ref_count_, and the deletion of si->self_.
-    // In that case, the deletion of si->self_ is deferred to ~signal_exec().
-    signal_exec exec(si->self_);
+    // In that case, the deletion of si->self_ is deferred to ~signal_impl_holder().
+    signal_impl_holder exec(si->self_);
     si->self_->slots_.erase(si->iter_);
   }
   else
   {
     // This is occuring during signal emission or slot erasure.
-    // => sweep() will be called from ~signal_exec() after signal emission.
+    // => sweep() will be called from ~signal_impl_holder() after signal emission.
     // This is safer because we don't have to care about our
     // iterators in emit(), clear(), and erase().
     si->self_->deferred_ = true;
@@ -202,13 +200,12 @@ signal_impl::notify(notifiable* d)
 
 } /* namespace internal */
 
-signal_base::signal_base() noexcept : impl_(nullptr)
+signal_base::signal_base() noexcept
 {
 }
 
 signal_base::signal_base(const signal_base& src) noexcept : trackable(), impl_(src.impl())
 {
-  impl_->reference();
 }
 
 signal_base::signal_base(signal_base&& src) : trackable(std::move(src)), impl_(std::move(src.impl_))
@@ -218,10 +215,6 @@ signal_base::signal_base(signal_base&& src) : trackable(std::move(src)), impl_(s
 
 signal_base::~signal_base()
 {
-  if (impl_)
-  {
-    impl_->unreference();
-  }
 }
 
 void
@@ -293,13 +286,7 @@ signal_base::operator=(const signal_base& src)
   if (src.impl_ == impl_)
     return *this;
 
-  if (impl_)
-  {
-    impl_->unreference();
-  }
-
   impl_ = src.impl();
-  impl_->reference();
   return *this;
 }
 
@@ -309,11 +296,6 @@ signal_base::operator=(signal_base&& src)
   if (src.impl_ == impl_)
     return *this;
 
-  if (impl_)
-  {
-    impl_->unreference();
-  }
-
   src.notify_callbacks();
   impl_ = src.impl_;
   src.impl_ = nullptr;
@@ -321,13 +303,12 @@ signal_base::operator=(signal_base&& src)
   return *this;
 }
 
-internal::signal_impl*
+std::shared_ptr<internal::signal_impl>
 signal_base::impl() const
 {
   if (!impl_)
   {
-    impl_ = new internal::signal_impl;
-    impl_->reference(); // start with a reference count of 1
+    impl_ = std::make_shared<internal::signal_impl>();
   }
   return impl_;
 }
