@@ -1,5 +1,4 @@
-// -*- c++ -*-
-/* Copyright 2002, The libsigc++ Development Team
+/* Copyright 2002 - 2016, The libsigc++ Development Team
  *  Assigned to public domain.  Use as you wish without restriction.
  */
 
@@ -33,23 +32,47 @@ main(int argc, char* argv[])
   {
     std::cout << "sizes of public classes:" << std::endl;
 
+    //libsigc++ 2.10: 8
+    //libsigc++ 3.0: 8
     std::cout << "  trackable:               " << sizeof(sigc::trackable) << std::endl;
+    
+    //libsigc++ 2.10: 16
+    //libsigc++ 3.0: 16
     std::cout << "  slot<void()>:              " << sizeof(sigc::slot<void()>) << std::endl;
+
+    //libsigc++ 2.10: 16
+    //libsigc++ 3.0: 16
     std::cout << "  signal<void()>:            " << sizeof(sigc::signal<void()>) << std::endl;
-    std::cout << "  signal<void()>::iterator:  " << sizeof(sigc::signal<void()>::iterator)
-              << std::endl;
+
+    //libsigc++ 2.10: 8
+    //libsigc++ 3.0: 8
     std::cout << "  connection:              " << sizeof(sigc::connection) << std::endl;
 
+
     std::cout << std::endl << "sizes of internal classes:" << std::endl;
 
+    //libsigc++ 2.10: 16
+    //libsigc++ 3.0: 16
     std::cout << "  trackable_callback:      " << sizeof(sigc::internal::trackable_callback)
               << std::endl;
+
+    //libsigc++ 2.10: 32
+    //libsigc++ 3.0: 32
     std::cout << "  trackable_callback_list: " << sizeof(sigc::internal::trackable_callback_list)
               << std::endl;
+
+    //libsigc++ 2.10: 48
+    //libsigc++ 3.0: 48
     std::cout << "  slot_rep:                " << sizeof(sigc::internal::slot_rep) << std::endl;
+
+    //libsigc++ 2.10: 72
+    //libsigc++ 3.0: 64
     std::cout << "  typed_slot_rep<mem_functor<void,A> >: "
               << sizeof(sigc::internal::typed_slot_rep<sigc::mem_functor<void (A::*)()>>)
               << std::endl;
+
+    //libsigc++ 2.10: 32
+    //libsigc++ 3.0: 32
     std::cout << "  signal_impl:             " << sizeof(sigc::internal::signal_impl) << std::endl;
   }
   return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
